@@ -1,2 +1,2 @@
 from dalle_pytorch.dalle_pytorch import DALLE, CLIP, DiscreteVAE
-from dalle_pytorch.vae import OpenAIDiscreteVAE
+from dalle_pytorch.vae import OpenAIDiscreteVAE, VQGanVAE1024
