@@ -364,7 +364,7 @@ class DALLE(nn.Module):
             ((seq_range < text_seq_len) & (logits_range >= num_text_tokens))
         )
 
-        self.register_buffer('logits_mask', logits_mask)
+        self.register_buffer('logits_mask', logits_mask, persistent=False)
         self.loss_img_weight = loss_img_weight
 
     @torch.no_grad()
